# delimit ;
clear;
set mem 100m;
set more off;

/* CREATES FIG. 3*/

/* CHANGE THIS LINE TO REFLECT LOCAL DIRECTORY STRUCTURE */
global REPDIR = "/Users/arienachi/Dropbox/Miguel/Website Content/Research/Published Papers/12. Civil War/Data Copy/";

/* IMPORT DATA */
use "$REPDIR/PRIO and WDI merged version 9.dta"

/*
Fan Locally-weighted nonparametric regression, quartic kernel

Refer to URL: www.worldbank.org/LSMS/tools/deaton, or the Deaton book

fan_reg performs the locally-weighted nonparametric regression:

argument 1 is the dependent variable (input)

argument 2 is the explanatory variable (input)

argument 3 is the estimated regression function (output)

argument 4 is the derivative of the regression function (output)

argument 5 is the bandwidth (input)

argument 6 is the grid over the explanatory variable for evaluation
*/;

cap program drop fan_reg;

program def fan_reg;

	/* ic is the loop counter */;

	local ic = 1;

	/* Generate the estimated function (3) and its derivative (4) */;

	gen `3' = .;	

	gen `4' = .;

	/* Loop until reaching the last cell of the grid */;

	while `ic' <= $gsize {;

	/* Display the counter */;

	display `ic';	

	quietly {;

	/* Get the ic entry in the grid */;

	local xx = `6'[`ic'];

	/* Absolute value of x - x(i), divided by the bandwidth */;

	gen z = abs((`2' - `xx')/`5');

	/* Observation i gets the following quartic kernel weight */;

	gen kz = (15/16)*(1 - z^2)^2 if z<=1;

	/* Perform the regression weighted by the kernel (analogous to GLS) */;

	reg  `1' `2' [aw=kz] if kz~=., robust;

	/* The estimated regression is the value at x */;

	replace `3' = _b[_cons]+_b[`2']*`xx' in `ic';

	/* The estimated slope is the coefficient estimate at x */;

	replace `4' = _b[`2'] in `ic';

	drop z kz;

	};

	local ic = `ic' + 1;

	};

end;


/*  Program bootstraps the locally weighted regression, without clustering */;
cap program drop fan_bts;

program def fan_bts;

local jc = 1;

while `jc' <= 200 {;

display `jc';

drop _all;
clear;


use temp;

/* This takes a sample of size _N (sample size), with replacement */;

bsample _N;

qui gen xgrid = $xmin + (_n-1)*$st in 1/$gsize;

qui fan_reg warinci2 pctgdp fxn der $h xgrid;

drop warinci2 pctgdp;

/* Only keep the regression results */;

keep in 1/$gsize;

gen replic = `jc';

/* "Stack" simulated regression results */;

append using lw_boot;

save lw_boot, replace;

local jc = `jc' + 1;

};

end;




/* Range of dependent variable */;

global xmin = 0;
global xmax = 1;

/* Number of points at which to calculate, 50 to 100 are typically fine */;

global gsize = 50;

/* Size of each step */;

global st = ($xmax - $xmin)/($gsize-1);

/* Bandwidth */;

global h = 0.3;

save temp, replace;

/* NEW DATASET FOR BOOTSTRAP SIMULATIONS */;

gen replic = 0;
gen fxn= .;
gen xgrid = .;
gen der= .;
keep in 1/1;
drop warinci2 pctgdp;
save lw_boot, replace;
clear;

/* Perform the bootstrap */;

fan_bts;
clear;

/* Recover the standard errors */;

use lw_boot;

/* Drop the "useless" initial values */;

drop if replic == 0;
sort xgrid replic;
save lw_boot2, replace;

/* Compute the variation at each grid point */;

egen sd = sd(fxn), by(xgrid);

/* Only keep the standard errors */;

sort xgrid;

/* Only keep the first observation at each grid point */;

quietly by xgrid: drop if _n ~= 1;
save lw_boot, replace;
clear;

/* Perform the Fan regression */

use temp, clear;
gen xgrid = $xmin +(_n-1)*$st in 1/$gsize;
qui fan_reg warinci2 pctgdp fxn der $h xgrid; 
sort xgrid;

/* Keep only the regression output */;

keep in 1/$gsize;

/* Merge the bootstrap standard error results */;

merge xgrid using lw_boot;
drop _merge;
sort xgrid;
save lw_boot, replace;
clear;

/* Compute 95 percent confidence bands */;

use lw_boot;
gen diff_u1 = fxn + 2*sd;
gen diff_l1 = fxn - 2*sd;

sort xgrid;

/* Graph the function and bounds */;

label var diff_l1 "95% lower band";
label var diff_u1 "95% upper band";
label var xgrid "GDP per capita";
label var fxn "Fan Regression";

twoway (line diff_u1 xgrid, sort clpat(dash) ytitle(Incidence of Civil War)) 
	(line diff_l1 xgrid, sort clpat(dash)) (line fxn xgrid);
graph export "$REPDIR/ Fig3.png", replace 
